==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/creative_tab/content/NPCSpawnEggCreativeTab.java <==
package cc.thonly.reverie_dreams.creative_tab.content;

import cc.thonly.reverie_dreams.Touhou;
import cc.thonly.reverie_dreams.entity.npc.NPCRole;
import cc.thonly.reverie_dreams.item.ModItems;
import cc.thonly.reverie_dreams.registry.RegistryManager;
import net.fabricmc.fabric.api.itemgroup.v1.ItemGroupEvents;
import net.minecraft.class_1761;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_2561;
import net.minecraft.class_5321;
import net.minecraft.class_7924;
import java.util.Collection;

public class NPCSpawnEggCreativeTab implements ItemGroupContentHelper {
    public static final class_5321<class_1761> ITEM_GROUP_KEY = class_5321.method_29179(class_7924.field_44688, Touhou.id("item_group_role_spawn_egg"));
    public static final class_1761 ITEM_GROUP = ItemGroupContentHelper.builder()
            .method_47320(() -> new class_1799(ModItems.SPAWN_EGG))
            .method_47321(class_2561.method_43471("item_group.touhou.role.spawn_egg"))
            .method_47324();

    public static void bootstrap() {
        ItemGroupEvents.modifyEntriesEvent(NPCSpawnEggCreativeTab.ITEM_GROUP_KEY).register(itemGroup -> {
            Collection<NPCRole> roles = RegistryManager.NPC_ROLE.values();
            for (NPCRole role : roles) {
                class_1792 egg = role.getEgg();
                itemGroup.method_45420(egg.method_7854());
            }
        });
        ItemGroupContentHelper.registerGroup(NPCSpawnEggCreativeTab.ITEM_GROUP_KEY, NPCSpawnEggCreativeTab.ITEM_GROUP);
    }
}

==> reverie_dreams-0.4.7%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/creative_tab/content/NPCSpawnEggCreativeTab.java <==
package cc.thonly.reverie_dreams.creative_tab.content;

import cc.thonly.reverie_dreams.ReverieDreams;
import cc.thonly.reverie_dreams.data.npc.NPCRole;
import cc.thonly.reverie_dreams.registry.content.item.RDItems;
import cc.thonly.reverie_dreams.registry.RegistryHandlers;
import net.fabricmc.fabric.api.itemgroup.v1.ItemGroupEvents;
import net.minecraft.class_1761;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_2561;
import net.minecraft.class_5321;
import net.minecraft.class_7924;
import java.util.Collection;

public class NPCSpawnEggCreativeTab implements ItemGroupContentHelper {
    public static final class_5321<class_1761> ITEM_GROUP_KEY = class_5321.method_29179(class_7924.field_44688, ReverieDreams.id("item_group_role_spawn_egg"));
    public static final class_1761 ITEM_GROUP = ItemGroupContentHelper.builder()
            .method_47320(() -> new class_1799(RDItems.SPAWN_EGG))
            .method_47321(class_2561.method_43471("item_group.touhou.role.spawn_egg"))
            .method_47324();

    public static void bootstrap() {
        ItemGroupEvents.modifyEntriesEvent(NPCSpawnEggCreativeTab.ITEM_GROUP_KEY).register(itemGroup -> {
            Collection<NPCRole> roles = RegistryHandlers.NPC_ROLE.values();
            for (NPCRole role : roles) {
                class_1792 egg = role.getEgg();
                itemGroup.method_45420(egg.method_7854());
            }
        });
        ItemGroupContentHelper.registerGroup(NPCSpawnEggCreativeTab.ITEM_GROUP_KEY, NPCSpawnEggCreativeTab.ITEM_GROUP);
    }
}
